/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
/// <reference types="node" />
import { EventEmitter } from "events";
import { ICheckpointService, IClientManager, IContext, IClusterDrainingChecker, IDocumentRepository, IPartitionLambda, IPartitionLambdaConfig, IPartitionLambdaFactory, IProducer, IServiceConfiguration, ITenantManager, MongoManager } from "@fluidframework/server-services-core";
/**
 * @internal
 */
export declare class DeliLambdaFactory extends EventEmitter implements IPartitionLambdaFactory<IPartitionLambdaConfig> {
    private readonly operationsDbMongoManager;
    private readonly documentRepository;
    private readonly checkpointService;
    private readonly tenantManager;
    private readonly clientManager;
    private readonly forwardProducer;
    private readonly signalProducer;
    private readonly reverseProducer;
    private readonly serviceConfiguration;
    private readonly clusterDrainingChecker?;
    private readonly ephemeralDocumentTTLSec?;
    constructor(operationsDbMongoManager: MongoManager, documentRepository: IDocumentRepository, checkpointService: ICheckpointService, tenantManager: ITenantManager, clientManager: IClientManager | undefined, forwardProducer: IProducer, signalProducer: IProducer | undefined, reverseProducer: IProducer, serviceConfiguration: IServiceConfiguration, clusterDrainingChecker?: IClusterDrainingChecker | undefined, ephemeralDocumentTTLSec?: number | undefined);
    create(config: IPartitionLambdaConfig, context: IContext, updateActivityTime?: (activityTime?: number) => void): Promise<IPartitionLambda>;
    private logSessionFailureMetrics;
    dispose(): Promise<void>;
    private isEphemeralDocumentWithinTtl;
    private loadStateFromSummary;
}
//# sourceMappingURL=lambdaFactory.d.ts.map