"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidConnectionMessage = exports.checkProtocolVersion = exports.ProtocolVersions = void 0;
const server_services_client_1 = require("@fluidframework/server-services-client");
const semver = __importStar(require("semver"));
const server_services_telemetry_1 = require("@fluidframework/server-services-telemetry");
exports.ProtocolVersions = ["^0.4.0", "^0.3.0", "^0.2.0", "^0.1.0"];
function selectProtocolVersion(connectVersions) {
    for (const connectVersion of connectVersions) {
        for (const protocolVersion of exports.ProtocolVersions) {
            if (semver.intersects(protocolVersion, connectVersion)) {
                return protocolVersion;
            }
        }
    }
    return undefined;
}
function checkProtocolVersion(versions) {
    // Iterate over the version ranges provided by the client and select the best one that works
    const connectVersions = versions || ["^0.1.0"];
    const version = selectProtocolVersion(connectVersions);
    if (!version) {
        server_services_telemetry_1.Lumberjack.error(`Unsupported client protocol.`, {
            server: exports.ProtocolVersions,
            client: connectVersions,
        });
        throw new server_services_client_1.NetworkError(400, `Unsupported client protocol. Server: ${exports.ProtocolVersions}. Client: ${connectVersions}`);
    }
    return [connectVersions, version];
}
exports.checkProtocolVersion = checkProtocolVersion;
function isValidClientDetails(details) {
    return (typeof details === "object" &&
        details !== null &&
        typeof details.capabilities === "object" &&
        details.capabilities !== null &&
        typeof details.capabilities.interactive === "boolean" &&
        (typeof details.type === "string" ||
            details.type === undefined) &&
        (typeof details.environment === "string" ||
            details.environment === undefined) &&
        (typeof details.device === "string" ||
            details.device === undefined));
}
function isValidUser(user) {
    return typeof user === "object" && user !== null && "id" in user && typeof user.id === "string";
}
function isValidClient(client) {
    return (typeof client === "object" &&
        client !== null &&
        (client.mode === "write" || client.mode === "read") &&
        isValidClientDetails(client.details) &&
        Array.isArray(client.permission) &&
        client.permission.every((p) => typeof p === "string") &&
        isValidUser(client.user) &&
        Array.isArray(client.scopes) &&
        client.scopes.every((s) => typeof s === "string") &&
        (typeof client.timestamp === "number" ||
            client.timestamp === undefined));
}
/**
 * Assert that the given message is a valid connect_document message from a client.
 *
 * @internal
 */
function isValidConnectionMessage(message) {
    return (typeof message === "object" &&
        message !== null &&
        typeof message.tenantId === "string" &&
        typeof message.id === "string" &&
        // According to protocol definitions, this can be string or null, but is
        // expected to eventually be string or undefined.
        (typeof message.token === "string" ||
            message.token === null ||
            message.token === undefined) &&
        isValidClient(message.client) &&
        Array.isArray(message.versions) &&
        message.versions.every((v) => typeof v === "string") &&
        (typeof message.driverVersion === "string" ||
            message.driverVersion === undefined) &&
        (message.mode === "write" || message.mode === "read") &&
        (typeof message.nonce === "string" ||
            message.nonce === undefined) &&
        (typeof message.epoch === "string" ||
            message.epoch === undefined) &&
        (typeof message.supportedFeatures === "object" ||
            message.supportedFeatures === undefined) &&
        (typeof message.relayUserAgent === "string" ||
            message.relayUserAgent === undefined));
}
exports.isValidConnectionMessage = isValidConnectionMessage;
//# sourceMappingURL=protocol.js.map