"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.isSentSignalMessage = exports.getClientSpecificRoomId = exports.getRoomId = exports.isSummarizer = exports.SummarizerClientType = exports.isWriter = exports.hasWriteAccess = exports.ExpirationTimer = exports.handleServerErrorAndConvertToNetworkError = exports.getMessageMetadata = void 0;
const server_services_client_1 = require("@fluidframework/server-services-client");
const server_services_telemetry_1 = require("@fluidframework/server-services-telemetry");
const getMessageMetadata = (documentId, tenantId, correlationId) => ({
    documentId,
    tenantId,
    correlationId,
});
exports.getMessageMetadata = getMessageMetadata;
function handleServerErrorAndConvertToNetworkError(logger, errorMessage, documentId, tenantId, error) {
    const errMsgWithPrefix = `Connect Server Error - ${errorMessage}`;
    const correlationId = (0, server_services_telemetry_1.getGlobalTelemetryContext)().getProperties().correlationId;
    logger.error(errMsgWithPrefix, {
        messageMetaData: (0, exports.getMessageMetadata)(documentId, tenantId, correlationId),
    });
    server_services_telemetry_1.Lumberjack.error(errMsgWithPrefix, (0, server_services_telemetry_1.getLumberBaseProperties)(documentId, tenantId), error);
    return new server_services_client_1.NetworkError(500, `Failed to connect client to document. Check correlation Id ${correlationId} for details.`);
}
exports.handleServerErrorAndConvertToNetworkError = handleServerErrorAndConvertToNetworkError;
class ExpirationTimer {
    constructor(onTimeout) {
        this.onTimeout = onTimeout;
    }
    clear() {
        if (this.timer !== undefined) {
            clearTimeout(this.timer);
            this.timer = undefined;
        }
    }
    set(mSecUntilExpiration) {
        this.clear();
        this.timer = setTimeout(() => {
            this.onTimeout();
            this.clear();
        }, mSecUntilExpiration);
    }
}
exports.ExpirationTimer = ExpirationTimer;
const hasWriteAccess = (scopes) => (0, server_services_client_1.canWrite)(scopes) || (0, server_services_client_1.canSummarize)(scopes);
exports.hasWriteAccess = hasWriteAccess;
const isWriter = (scopes, mode) => (0, exports.hasWriteAccess)(scopes) && mode === "write";
exports.isWriter = isWriter;
exports.SummarizerClientType = "summarizer";
const isSummarizer = (clientDetails) => clientDetails.type === exports.SummarizerClientType || clientDetails.capabilities.interactive === false;
exports.isSummarizer = isSummarizer;
const getRoomId = (room) => `${room.tenantId}/${room.documentId}`;
exports.getRoomId = getRoomId;
const getClientSpecificRoomId = (clientId) => `client#${clientId}`;
exports.getClientSpecificRoomId = getClientSpecificRoomId;
function isSentSignalMessage(obj) {
    return (typeof obj === "object" &&
        obj !== null &&
        "content" in obj &&
        (!("type" in obj) || typeof obj.type === "string") &&
        (!("clientConnectionNumber" in obj) || typeof obj.clientConnectionNumber === "number") &&
        (!("referenceSequenceNumber" in obj) || typeof obj.referenceSequenceNumber === "number") &&
        (!("targetClientId" in obj) || typeof obj.targetClientId === "string"));
}
exports.isSentSignalMessage = isSentSignalMessage;
//# sourceMappingURL=utils.js.map